Plane class

Defines a plane with a normal vector and a constant.

Constructors

Plane()
Create a plane with a zero normal and zero constant.
Plane.components(double x, double y, double z, double constant)
Create a plane from normal components and a constant.
Plane.copy(Plane other)
Create a plane as a copy of other.
Plane.normalconstant(Vector3 normal_, double constant)
Create a plane from a normal vector and a constant.

Properties

constant double
The constant term in the plane equation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
normal Vector3
The normal vector of the plane.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyFrom(Plane o) → void
Copy the normal and constant from o into this.
distanceToVector3(Vector3 point) double
Return the signed distance from point to this plane.
normalize() → void
Normalize this plane so that normal has unit length.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFromComponents(double x, double y, double z, double w) → void
Set the normal components and constant term of this plane.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

intersection(Plane a, Plane b, Plane c, Vector3 result) → void
Find the intersection point between the three planes a, b and c and copy it into result.