postmultiply method

void postmultiply(
  1. Matrix3 arg
)

Transforms this into the product of this as a row vector, postmultiplied by matrix, arg.

If arg is a rotation matrix, this is a computational shortcut for applying, the inverse of the transformation.

Implementation

void postmultiply(Matrix3 arg) {
  final Float64List argStorage = arg._m3storage;
  final double v2 = _v3storage[2];
  final double v1 = _v3storage[1];
  final double v0 = _v3storage[0];

  _v3storage[2] = v0 * argStorage[6] + v1 * argStorage[7] + v2 * argStorage[8];
  _v3storage[1] = v0 * argStorage[3] + v1 * argStorage[4] + v2 * argStorage[5];
  _v3storage[0] = v0 * argStorage[0] + v1 * argStorage[1] + v2 * argStorage[2];
}