VertexAttrib class

Constructors

VertexAttrib(String name, int size, String type)
VertexAttrib.copy(VertexAttrib attrib)

Properties

elementSize → int
no setter
format → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
offset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final
stride → int
final
type → String
final

Methods

getView(Float32List buffer) → VectorList<Vector>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited